@@ -330,6 +330,13 @@ class Point(BaseGeometry):
 	def __init__(self, geo: geom.Point, crs: str, features: dict):
 		super().__init__(geo, crs, features)
 
+class MultiPoint(BaseGeometry):
+
+	parent_class = geom.MultiPoint
+
+	def __init__(self, geo: geom.MultiPoint, crs: str, features: dict):
+		super().__init__(geo, crs, features)
+
 class LineString(BaseGeometry):
 
 	parent_class = geom.LineString
@@ -337,6 +344,12 @@ class LineString(BaseGeometry):
 	def __init__(self, geo: geom.LineString, crs: str, features: dict):
 		super().__init__(geo, crs, features)
 
+class MultiLineString(BaseGeometry):
+
+	parent_class = geom.MultiLineString
+
+	def __init__(self, geo: geom.MultiLineString, crs: str, features: dict):
+		super().__init__(geo, crs, features)
 
 class Polygon(BaseGeometry):
 
@@ -363,8 +376,12 @@ def enrich_geom(geo, features, pcs='EPSG:4326'):
 	"""Enrich a shapely geometry with old features"""
 	if isinstance(geo, geom.Point):
 		return Point(geo, pcs, features)
+	elif isinstance(geo, geom.MultiPoint):
+		return MultiPoint(geo, pcs, features)
 	elif isinstance(geo, geom.LineString):
 		return LineString(geo, pcs, features)
+	elif isinstance(geo, geom.MultiLineString):
+		return MultiLineString(geo, pcs, features)
 	elif isinstance(geo, geom.Polygon):
 		return Polygon(geo, pcs, features)
 	elif isinstance(geo, geom.MultiPolygon):
